@@ -9,7 +9,7 @@ class PipelineTransformations(object):
 
     @staticmethod
     def clean_df(df):
-        df = df.replace({np.nan: None, '': None})
+        df = df.replace({np.nan: None, '': None, 'none': None})
 
         return df
 
